# Flumel

[![Construction](https://gitlab.com/canarduck/flumel/badges/master/pipeline.svg)](https://gitlab.com/canarduck/flumel/commits/master) [![couverture des tests](https://gitlab.com/canarduck/flumel/badges/master/coverage.svg)](https://gitlab.com/canarduck/flumel)

Encore un moyen de recevoir ses flux RSS par email

* Documentation : https://flumel.readthedocs.io/fr/latest/
* Dépôt : https://gitlab.com/canarduck/flumel